@@ -32,14 +32,14 @@ except:
 main module of ansiblator - wrapper around ansible
 """
 try:
-    from .version import __version__
+    from ansiblator.version import __version__
 except ImportError:
     __version__ = 0
 
 __version__ = "0.5-{}".format(__version__)
-__author__ = "Zdenek Dlauhy"
+__author__ = "Zdenek Dlauhy, Michal Dlauhy"
 __email__ = "test@dlauhy.cz"
-__url__ = "http://pripravto.cz"
+__url__ = "http://www.pripravto.cz"
 __desc__ = "Ansiblator - make ansible api more pythonic and usefull"
 __sys_name__ = "ansiblator"
 __license__ = "MIT"
@@ -126,7 +126,11 @@ class Ansiblator(object):
     ==============
 
     For most quickest example you can just create your ansible file named
-    ansible_hosts inside your home directory or full path
+    ansible_hosts inside your home directory or full path.
+
+    Ansiblater is mainly using file such as in ~/ansible_hosts
+
+    code::
 
         from ansiblator.api import Ansiblator
         ans = Ansiblator()
@@ -136,24 +140,40 @@ class Ansiblator(object):
         ans.run_all()
         ans.copy(src="/tmp/aabc.csv", dest="/tmp/",pattern="pc",now=True)
 
+    use dictionary::
+
+        inv = {'pc':[{'ssh_host':'192.168.0.10', 'ssh_user':'test_user', 'su_user':'root'}}
+        ans = Ansiblator(inventory=inv)
+        ans.run("uname -a", now=True)
+
+
     More useable way
     ================
 
     Ansiblator automatically save return json values for actuall runs, so
-    you can use them for testing and conditions
+    you can use them for testing and conditions. For example
 
+    testing::
+
+        return_code = ans.run("uname -a", now=True, use_shell=True)
+        return_code['contacted']
+
+        or
+
+        return_code = ans.run(["uname", "-a"], now=True, use_shell=False)
+        return_code['contacted']
 
     Info
     ====
     For more information consult functions or ansible documentation.
     more information can be also used on www.pripravto.cz. You can also
-    contact me there
+    contact us there.
 
 
     """
     def __init__(self, inventory="ansible_hosts", pattern="all",
                  module_name="command", run_at_once=False, sudo=False, su=False,
-                 su_user=None, host=None, stop_on_error=False, use_shell=False):
+                 su_user=None, host=None, stop_on_error=True, use_shell=True):
         """
         :param inventory: string or dict, which defines inventory
         :type inventory: str or dict
@@ -292,7 +312,7 @@ class Ansiblator(object):
                                        sudo_pass=sudo_pass)
         return self._run(runner, now)
 
-    def runner_local(self, cmd="uptime", module_name=None, now=None, **kwargs):
+    def runner_local(self, cmd="uptime", module_name=None, now=None, use_shell=None, **kwargs):
         """
         :param cmd: command to run
         :type cmd: str
@@ -304,7 +324,7 @@ class Ansiblator(object):
         if now is None:
             now = self.run_at_once
         runner = {'cmd':cmd, 'module_name':module_name}
-        return self._run(runner, now)
+        return self._run(runner, now, use_shell)
 
     def _run(self, runner, now=None, use_shell=None):
         """
@@ -322,19 +342,26 @@ class Ansiblator(object):
         if now:
             log.info("Running {}".format(runner))
             if isinstance(runner, dict):
-                # TODO: Check output
-                ret_code = subprocess.Popen(runner['cmd'], stdout=subprocess.PIPE, shell=use_shell)
-                out, err = ret_code.communicate()
-                if err == 0:
+                try:
+                    ret_code = subprocess.Popen(runner['cmd'], stdout=subprocess.PIPE, shell=use_shell)
+                    out, err = ret_code.communicate()
+                    return_c = ret_code.returncode
+                except OSError as e:
+                    log.error(e)
+                    return_c = 1
+                    out = None
+                    err = e
+
+                if return_c == 0:
                     failed = False
                 else:
                     failed = True
-                ret_code = {'contacted':{'local':{'stdout':out, 'failed':failed , 'stderr':err, 'ret_code':ret_code.returncode}}, 'dark':{}}
+                ret_code = {'contacted':{'local':{'stdout':out, 'failed':failed , 'stderr':err, 'ret_code':return_c}}, 'dark':{}}
             else:
                 ret_code = runner.run()
             self.parse_ret_code(ret_code)
             self.ret_codes.append(ret_code)
-            log.info(ret_code)
+            # log.info(ret_code)
             return ret_code
         else:
             self.runners.append(runner)
@@ -362,7 +389,7 @@ class Ansiblator(object):
         if use_ansible:
             return self.runner_ans(cmd=cmd, module_name=module_name, inventory=inventory, now=now, pattern=pattern, **kwargs)
         else:
-            return self.runner_local(cmd=cmd, module_name=module_name, inventory=inventory, now=now, pattern=pattern, **kwargs)
+            return self.runner_local(cmd=cmd, module_name=module_name, inventory=inventory, now=now, pattern=pattern, ** kwargs)
 
     run = runner
 
@@ -377,8 +404,8 @@ class Ansiblator(object):
     def ping(self, cmd=None, module_name="ping", **kwargs):
         return self.runner(cmd=cmd, use_ansible=True, module_name=module_name, **kwargs)
 
-    def local(self, cmd=None, use_shell=False, **kwargs):
-        return self.runner(cmd=cmd, use_ansible=False, use_shell=use_shell, **kwargs)
+    def local(self, cmd=None, **kwargs):
+        return self.runner(cmd=cmd, use_ansible=False, **kwargs)
     run_cmd = local
 
     def run_all(self, now=True):
@@ -406,8 +433,13 @@ class Ansiblator(object):
 __description__ = Ansiblator.__doc__
 
 if __name__ == "__main__":
-    ans = Ansiblator(pattern="pc")
+    ans = Ansiblator(pattern="pc", stop_on_error=False)
     ans.local(["uname", "-a"], now=True)
+    ans.local("uname -a", now=True)
+    ret = ans.local("uname -a", now=True, use_shell=True)
+    if ret['contacted']:
+        for k, v in ret['contacted'].items():
+            print(k, v.get('stdout', None), v.get("stderr", None))
     ans.run("uptime")
     ans.run("touch /tmp/aaa.csv")
     ans.local(["uname", "-a"])
